@@ -31,7 +31,8 @@ class Imu {
 	/**
 	 * Calibrate IMU
 	 *
-	 * This takes approximately 2 seconds, and is a non-blocking operation.
+	 * Calibration takes approximately 2 seconds, but this function only blocks
+ 	 * until the IMU status flag is set properly to E_IMU_STATUS_CALIBRATING.
 	 *
 	 * This function uses the following values of errno when an error state is
 	 * reached:
@@ -444,6 +445,9 @@ class Imu {
 	 */
 	virtual bool is_calibrating() const;
 };
+
+using IMU = Imu;
+
 }  // namespace pros
 
 #endif
