@@ -20,6 +20,7 @@
 #define _PROS_MOTORS_HPP_
 
 #include <cstdint>
+
 #include "pros/motors.h"
 
 namespace pros {
@@ -565,6 +566,7 @@ class Motor {
 	 *
 	 * \return A motor_pid_s_t struct formatted properly in 4.4.
 	 */
+	[[deprecated("Changing these values is not supported by VEX and may lead to permanent motor damage.")]]
 	static motor_pid_s_t convert_pid(double kf, double kp, double ki, double kd);
 
 	/**
@@ -594,8 +596,9 @@ class Motor {
 	 *
 	 * \return A motor_pid_s_t struct formatted properly in 4.4.
 	 */
-	static motor_pid_full_s_t convert_pid_full(double kf, double kp, double ki, double kd, double filter, double limit,
-	                                           double threshold, double loopspeed);
+	[[deprecated("Changing these values is not supported by VEX and may lead to permanent motor damage.")]] 
+	static motor_pid_full_s_t convert_pid_full(double kf, double kp, double ki, double kd, double filter, double limit, double threshold,
+	                 double loopspeed);
 
 	/**
 	 * Sets one of motor_pid_s_t for the motor. This intended to just modify the
@@ -614,6 +617,7 @@ class Motor {
 	 * \return 1 if the operation was successful or PROS_ERR if the operation
 	 * failed, setting errno.
 	 */
+	[[deprecated("Changing these values is not supported by VEX and may lead to permanent motor damage.")]]
 	virtual std::int32_t set_pos_pid(const motor_pid_s_t pid) const;
 
 	/**
@@ -632,6 +636,7 @@ class Motor {
 	 * \return 1 if the operation was successful or PROS_ERR if the operation
 	 * failed, setting errno.
 	 */
+	[[deprecated("Changing these values is not supported by VEX and may lead to permanent motor damage.")]] 
 	virtual std::int32_t set_pos_pid_full(const motor_pid_full_s_t pid) const;
 
 	/**
@@ -651,6 +656,7 @@ class Motor {
 	 * \return 1 if the operation was successful or PROS_ERR if the operation
 	 * failed, setting errno.
 	 */
+	[[deprecated("Changing these values is not supported by VEX and may lead to permanent motor damage.")]] 
 	virtual std::int32_t set_vel_pid(const motor_pid_s_t pid) const;
 
 	/**
@@ -669,6 +675,7 @@ class Motor {
 	 * \return 1 if the operation was successful or PROS_ERR if the operation
 	 * failed, setting errno.
 	 */
+	[[deprecated("Changing these values is not supported by VEX and may lead to permanent motor damage.")]] 
 	virtual std::int32_t set_vel_pid_full(const motor_pid_full_s_t pid) const;
 
 	/**
@@ -768,6 +775,7 @@ class Motor {
 	 * \return A motor_pid_full_s_t containing the position PID constants last set
 	 * to the given motor
 	 */
+	[[deprecated("Changing these values is not supported by VEX and may lead to permanent motor damage.")]] 
 	virtual motor_pid_full_s_t get_pos_pid(void) const;
 
 	/**
@@ -785,6 +793,7 @@ class Motor {
 	 * \return A motor_pid_full_s_t containing the velocity PID constants last set
 	 * to the given motor
 	 */
+	[[deprecated("Changing these values is not supported by VEX and may lead to permanent motor damage.")]]
 	virtual motor_pid_full_s_t get_vel_pid(void) const;
 
 	/**
